﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.IO.Ports;
using System.Runtime.InteropServices;

namespace tm_DIO
{
    public partial class Form1 : Form
    {
        IntPtr hPort;

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            //Get number of COM port and  assign COM port name to list in cmbComPort.
            foreach (string s in SerialPort.GetPortNames())
            {
                cmbComPort.Items.Add(s);
            }
            cmbComPort.SelectedIndex = 0;
            cmdModules.SelectedIndex = 0;
            btnOpenCOM.Enabled = true;
            btnCloseCOM.Enabled = false;
            btnWriteDO.Enabled = true;
            btnWriteDO_MF.Enabled = false;
            btnReadDI.Enabled = true;
            btnReadDI_MF.Enabled = false;
        }

        private void btnOpenCOM_Click(object sender, EventArgs e)
        {
            //Open com port
            hPort = PACNET.UART.Open(cmbComPort.Text + "," + txtBaurdRate.Text);

            if (hPort == (IntPtr)(-1))
            {
                MessageBox.Show("error code:0x" + PACNET.ErrHandling.GetLastError().ToString("X") + "," + PACNET.ErrHandling.GetErrorMessage(PACNET.ErrHandling.GetLastError()));
            }
            else
            {
                btnOpenCOM.Enabled = false;
                btnCloseCOM.Enabled = true;
            }
        }

        private void btnCloseCOM_Click(object sender, EventArgs e)
        {
            //Close com port
            PACNET.UART.Close(hPort);
            btnOpenCOM.Enabled = true;
            btnCloseCOM.Enabled = false;
        }

        private void btnReadDI_Click(object sender, EventArgs e)
        {
            uint DiValue = 0;
            uint DoValue = 0;
            bool iRet;

            //Read DIO data
            iRet = PACNET.PAC_IO.ReadDIO(hPort, PACNET.PAC_IO.PAC_REMOTE_IO(Convert.ToInt32(txtAddress.Text)), Convert.ToInt32(txtDIChannel.Text), Convert.ToInt32(txtDOChannel.Text), ref DiValue, ref DoValue);
            
            if (iRet == false)
                MessageBox.Show("error code:0x" + PACNET.ErrHandling.GetLastError().ToString("X") + "," + PACNET.ErrHandling.GetErrorMessage(PACNET.ErrHandling.GetLastError()));
            else
            {
                txtDIValue.Text = DiValue.ToString();
                txtDOValue.Text = DoValue.ToString();
            }
        }

        private void btnReadDI_MF_Click(object sender, EventArgs e)
        {
            uint DiValue = 0;
            uint DoValue = 0;
            bool iRet;

            //Read DI data
            iRet = PACNET.PAC_IO.ReadDIO_MF(hPort, PACNET.PAC_IO.PAC_REMOTE_IO(Convert.ToInt32(txtAddress.Text)), Convert.ToInt32(txtDIChannel.Text), Convert.ToInt32(txtDOChannel.Text), ref DiValue, ref DoValue);
            if (!iRet)
            {
                uint ec = PACNET.ErrHandling.GetLastError();
                MessageBox.Show("error code:0x" + PACNET.ErrHandling.GetLastError().ToString("X") + "," + PACNET.ErrHandling.GetErrorMessage(PACNET.ErrHandling.GetLastError()));
            }
            else
                txtDIValue.Text = DiValue.ToString("X");
        }

        private void btnWriteDO_Click(object sender, EventArgs e)
        {
            bool iRet;

            //Write DO data
            iRet = PACNET.PAC_IO.WriteDO(hPort, PACNET.PAC_IO.PAC_REMOTE_IO(Convert.ToInt32(txtAddress.Text)), Convert.ToInt32(txtDOChannel.Text), Convert.ToUInt32(txtDOValue.Text, 16));
            if (iRet == false)
                MessageBox.Show("error code:0x" + PACNET.ErrHandling.GetLastError().ToString("X") + "," + PACNET.ErrHandling.GetErrorMessage(PACNET.ErrHandling.GetLastError()));
        }

        private void btnWriteDO_MF_Click(object sender, EventArgs e)
        {
            bool iRet;

            //Write DO data
            iRet = PACNET.PAC_IO.WriteDO_MF(hPort, PACNET.PAC_IO.PAC_REMOTE_IO(Convert.ToInt32(txtAddress.Text)), Convert.ToInt32(txtDOChannel.Text), Convert.ToUInt32(txtDOValue.Text, 16));

            if (!iRet)
            {
                uint ec = PACNET.ErrHandling.GetLastError();
                MessageBox.Show("error code:0x" + PACNET.ErrHandling.GetLastError().ToString("X") + "," + PACNET.ErrHandling.GetErrorMessage(PACNET.ErrHandling.GetLastError()));
            }
        }

        private void cmdModules_SelectedIndexChanged(object sender, EventArgs e)
        {
            switch (cmdModules.Text)
            {
                case "tM-P4A4":
                case "tM-P4C4":
                    txtDIChannel.Text = "4";
                    txtDOChannel.Text = "4";
                    btnWriteDO.Enabled = true;
                    btnWriteDO_MF.Enabled = false;
                    btnReadDI.Enabled = true;
                    btnReadDI_MF.Enabled = false;
                    break;
                case "tM-C8":
                    txtDIChannel.Text = "0";
                    txtDOChannel.Text = "8";
                    btnWriteDO.Enabled = true;
                    btnWriteDO_MF.Enabled = false;
                    btnReadDI.Enabled = true;
                    btnReadDI_MF.Enabled = false;
                    break;
                case "tM-P8":
                    txtDIChannel.Text = "8";
                    txtDOChannel.Text = "0";
                    btnWriteDO.Enabled = true;
                    btnWriteDO_MF.Enabled = false;
                    btnReadDI.Enabled = true;
                    btnReadDI_MF.Enabled = false;
                    break;
                case "tM-P3R3":
                    txtDIChannel.Text = "3";
                    txtDOChannel.Text = "3";
                    btnWriteDO.Enabled = true;
                    btnWriteDO_MF.Enabled = false;
                    btnReadDI.Enabled = true;
                    btnReadDI_MF.Enabled = false;
                    break;
                case "tM-R5":
                    txtDIChannel.Text = "0";
                    txtDOChannel.Text = "5";
                    btnWriteDO.Enabled = true;
                    btnWriteDO_MF.Enabled = false;
                    btnReadDI.Enabled = true;
                    btnReadDI_MF.Enabled = false;
                    break;
                case "tM-P3POR3":
                    txtDIChannel.Text = "3";
                    txtDOChannel.Text = "3";
                    btnWriteDO.Enabled = true;
                    btnWriteDO_MF.Enabled = false;
                    btnReadDI.Enabled = true;
                    btnReadDI_MF.Enabled = false;
                    break;
                case "tM-DA1P1R1":
                    txtDIChannel.Text = "1";
                    txtDOChannel.Text = "1";
                    btnWriteDO.Enabled = false;
                    btnWriteDO_MF.Enabled = true;
                    btnReadDI.Enabled = false;
                    btnReadDI_MF.Enabled = true;
                    break;
            }
        }
    }
}
